@@ -4,7 +4,7 @@ use strict;
 use Carp;
 use base qw(Unicode::Collate);
 
-our $VERSION = '0.62';
+our $VERSION = '0.64';
 
 use File::Spec;
 
@@ -14,12 +14,16 @@ my $PL_EXT  = '.pl';
 
 my %LocaleFile = map { ($_, $_) } qw(
    af ar az ca cs cy da eo es et fi fil fo fr ha haw
-   hr hu hy ig is kl lt lv mt nb nn nso om pl ro
+   hr hu hy ig is ja kk kl lt lv mt nb nn nso om pl ro ru
    se sk sl sq sv sw tn to tr uk vi wo yo
 );
    $LocaleFile{'default'}         = '';
    $LocaleFile{'de__phonebook'}   = 'de_phone';
    $LocaleFile{'es__traditional'} = 'es_trad';
+   $LocaleFile{'be'} = "ru";
+   $LocaleFile{'bg'} = "ru";
+   $LocaleFile{'mk'} = "ru";
+   $LocaleFile{'sr'} = "ru";
 
 sub _locale {
     my $locale = shift;
@@ -84,11 +88,22 @@ Unicode::Collate::Locale - Linguistic tailoring for DUCET via Unicode::Collate
 
   use Unicode::Collate::Locale;
 
+  #construct
   $Collator = Unicode::Collate::Locale->
       new(locale => $locale_name, %tailoring);
 
+  #sort
   @sorted = $Collator->sort(@not_sorted);
 
+  #compare
+  $result = $Collator->cmp($a, $b); # returns 1, 0, or -1.
+
+B<Note:> Strings in C<@not_sorted>, C<$a> and C<$b> are interpreted
+according to Perl's Unicode support. See L<perlunicode>,
+L<perluniintro>, L<perlunitut>, L<perlunifaq>, L<utf8>.
+Otherwise you can use C<preprocess> (cf. C<Unicode::Collate>)
+or should decode them before.
+
 =head1 DESCRIPTION
 
 This module provides linguistic tailoring for it
@@ -158,6 +173,8 @@ this method returns a string C<'default'> meaning no special tailoring.
       af                Afrikaans
       ar                Arabic
       az                Azerbaijani (Azeri)
+      be                Belarusian
+      bg                Bulgarian
       ca                Catalan
       cs                Czech
       cy                Welsh
@@ -178,9 +195,12 @@ this method returns a string C<'default'> meaning no special tailoring.
       hy                Armenian
       ig                Igbo
       is                Icelandic
+      ja                Japanese [1]
+      kk                Kazakh
       kl                Kalaallisut
       lt                Lithuanian
       lv                Latvian
+      mk                Macedonian
       mt                Maltese
       nb                Norwegian Bokmal
       nn                Norwegian Nynorsk
@@ -188,10 +208,12 @@ this method returns a string C<'default'> meaning no special tailoring.
       om                Oromo
       pl                Polish
       ro                Romanian
+      ru                Russian
       se                Northern Sami
       sk                Slovak
       sl                Slovenian
       sq                Albanian
+      sr                Serbian
       sv                Swedish
       sw                Swahili
       tn                Tswana
@@ -201,13 +223,38 @@ this method returns a string C<'default'> meaning no special tailoring.
       vi                Vietnamese
       wo                Wolof
       yo                Yoruba
+    ----------------------------------------------------------
+
+Locales according to the default UCA rules include
+de (German),
+en (English),
+ga (Irish),
+id (Indonesian),
+it (Italian),
+ka (Georgian),
+ln (Lingala),
+ms (Malay),
+nl (Dutch),
+pt (Portuguese),
+st (Southern Sotho),
+xh (Xhosa),
+zu (Zulu).
+
+B<Note>
+
+[1] ja: Ideographs are sorted in JIS X 0208 order.
+Fullwidth and halfwidth forms are identical to their normal form.
+The difference between hiragana and katakana is at the 4th level,
+the comparison also requires C<(variable =E<gt> 'Non-ignorable')>,
+and then C<katakana_before_hiragana> has no effect.
 
 =head1 INSTALL
 
-Installation of Unicode::Collate::Locale requires F<Collate/Locale.pm>,
-F<Collate/Locale/*.pm> and F<Collate/allkeys.txt>.  On building,
-Unicode::Collate::Locale doesn't require F<data/*.txt> and F<mklocale>.
-Tests for Unicode::Collate::Locale are named F<t/loc_*.t>.
+Installation of C<Unicode::Collate::Locale> requires F<Collate/Locale.pm>,
+F<Collate/Locale/*.pm>, F<Collate/CJK/*.pm> and F<Collate/allkeys.txt>.
+On building, C<Unicode::Collate::Locale> doesn't require any of F<data/*.txt>,
+F<gendata/*>, and F<mklocale>.
+Tests for C<Unicode::Collate::Locale> are named F<t/loc_*.t>.
 
 =head1 CAVEAT
 
@@ -215,7 +262,7 @@ Tests for Unicode::Collate::Locale are named F<t/loc_*.t>.
 
 =item tailoring is not maximum
 
-If a certain letter is tailored, its equivalents are not always
+Even if a certain letter is tailored, its equivalent would not always
 tailored as well as it. For example, even though W is tailored,
 fullwidth W (C<U+FF37>), W with acute (C<U+1E82>), etc. are not
 tailored. The result may depend on whether source strings are
@@ -246,6 +293,10 @@ L<http://www.unicode.org/reports/tr10/>
 
 L<http://www.unicode.org/Public/UCA/latest/allkeys.txt>
 
+=item Unicode Locale Data Markup Language (LDML) - UTS #35
+
+L<http://www.unicode.org/reports/tr35/>
+
 =item CLDR - Unicode Common Locale Data Repository
 
 L<http://cldr.unicode.org/>
